import { forceNumber } from '@peertube/peertube-core-utils';
import { Op, Sequelize } from 'sequelize';
export async function getNextPositionOf(options) {
    const { columnName, model, where, transaction } = options;
    const query = {
        where,
        transaction
    };
    const position = await model.max(columnName, query);
    return position
        ? position + 1
        : 1;
}
export function reassignPositionOf(options) {
    const { firstPosition, endPosition, newPosition, model, where, columnName, transaction } = options;
    const query = {
        where: Object.assign(Object.assign({}, where), { [columnName]: {
                [Op.gte]: firstPosition,
                [Op.lte]: endPosition
            } }),
        transaction,
        validate: false
    };
    const escapedColumnName = model.sequelize.escape(columnName).replace(/'/g, '');
    const positionQuery = Sequelize.literal(`${forceNumber(newPosition)} + "${escapedColumnName}" - ${forceNumber(firstPosition)}`);
    return model.update({ [columnName]: positionQuery }, query);
}
export function increasePositionOf(options) {
    const { model, where, transaction, fromPosition, by, columnName } = options;
    const query = {
        where: Object.assign(Object.assign({}, where), { [columnName]: {
                [Op.gte]: fromPosition
            } }),
        transaction
    };
    return model.increment({ [columnName]: by }, query);
}
//# sourceMappingURL=position.js.map